HiiString

Struct HiiString 

pub struct HiiString;

Methods from Deref<Target = Guid>

pub fn as_fields(&self) -> (u32, u16, u16, u8, u8, &[u8; 6])

Access a Guid as individual fields

This decomposes a Guid back into the individual fields as given in the specification. The individual fields are returned in native-endianness.

pub fn as_bytes(&self) -> &[u8; 16]

Access a Guid as raw byte array

This provides access to a Guid through a byte array. It is a simple re-interpretation of the Guid value as a 128-bit byte array. No conversion is performed. This is a simple cast.