pub struct StandardBootServices<'a> { /* private fields */ }Expand description
This is the boot services used in the UEFI.
it wraps an atomic ptr to efi::BootServices
Implementations
Sourceimpl<'a> StandardBootServices<'a>
impl<'a> StandardBootServices<'a>
Sourcepub const fn new(efi_boot_services: &'a BootServices) -> Self
pub const fn new(efi_boot_services: &'a BootServices) -> Self
Create a new StandardBootServices with the provided efi::BootServices.
Sourcepub const fn new_uninit() -> Self
pub const fn new_uninit() -> Self
Create a new StandardBootServices that is uninitialized. The struct need to be initialize later with Self::initialize, otherwise, subsequent call will panic.
Sourcepub fn initialize(&'a self, efi_boot_services: &'a BootServices)
pub fn initialize(&'a self, efi_boot_services: &'a BootServices)
Initialize the StandardBootServices with a reference to efi::BootServices.
Panics
This function will panic if already initialize.