StandardBootServices

Struct StandardBootServices 

pub struct StandardBootServices<'a> { /* private fields */ }
This is the boot services used in the UEFI. it wraps an atomic ptr to efi::BootServices

Implementations

Source

impl<'a> StandardBootServices<'a>

pub const fn new(efi_boot_services: &'a BootServices) -> Self

Create a new StandardBootServices with the provided efi::BootServices.

pub const fn new_uninit() -> Self

Create a new StandardBootServices that is uninitialized. The struct need to be initialize later with Self::initialize, otherwise, subsequent call will panic.

pub fn initialize(&'a self, efi_boot_services: &'a BootServices)

Initialize the StandardBootServices with a reference to efi::BootServices.

Panics

This function will panic if already initialize.